@@ -4,7 +4,9 @@ package start
 
 import (
 	"context"
+	"crypto/tls"
 	"fmt"
+	"io/ioutil"
 	"math/rand"
 	"os"
 	"os/signal"
@@ -25,13 +27,14 @@ import (
 	"k8s.io/client-go/tools/leaderelection/resourcelock"
 	"k8s.io/client-go/tools/record"
 	"k8s.io/client-go/util/flowcontrol"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	clientset "github.com/openshift/client-go/config/clientset/versioned"
 	externalversions "github.com/openshift/client-go/config/informers/externalversions"
 	"github.com/openshift/cluster-version-operator/pkg/autoupdate"
 	"github.com/openshift/cluster-version-operator/pkg/cvo"
 	"github.com/openshift/cluster-version-operator/pkg/internal"
+	"github.com/openshift/library-go/pkg/crypto"
 )
 
 const (
@@ -40,14 +43,20 @@ const (
 
 	minResyncPeriod = 2 * time.Minute
 
-	leaseDuration = 90 * time.Second
-	renewDeadline = 45 * time.Second
-	retryPeriod   = 30 * time.Second
+	// TODO set the slower lease values after we're able to reliably shut down gracefully.  This fixes the slow status update for now.
+	//leaseDuration = 90 * time.Second
+	//renewDeadline = 45 * time.Second
+	//retryPeriod   = 30 * time.Second
+	leaseDuration = 30 * time.Second
+	renewDeadline = 15 * time.Second
+	retryPeriod   = 10 * time.Second
 )
 
 // Options are the valid inputs to starting the CVO.
 type Options struct {
-	ReleaseImage string
+	ReleaseImage    string
+	ServingCertFile string
+	ServingKeyFile  string
 
 	Kubeconfig string
 	NodeName   string
@@ -104,6 +113,12 @@ func (o *Options) Run(ctx context.Context) error {
 	if o.ReleaseImage == "" {
 		return fmt.Errorf("missing --release-image flag, it is required")
 	}
+	if o.ServingCertFile == "" && o.ServingKeyFile != "" {
+		return fmt.Errorf("--serving-key-file was set, so --serving-cert-file must also be set")
+	}
+	if o.ServingKeyFile == "" && o.ServingCertFile != "" {
+		return fmt.Errorf("--serving-cert-file was set, so --serving-key-file must also be set")
+	}
 	if len(o.PayloadOverride) > 0 {
 		klog.Warningf("Using an override payload directory for testing only: %s", o.PayloadOverride)
 	}
@@ -131,6 +146,28 @@ func (o *Options) Run(ctx context.Context) error {
 	return nil
 }
 
+func (o *Options) makeTLSConfig() (*tls.Config, error) {
+	// Load the initial certificate contents.
+	certBytes, err := ioutil.ReadFile(o.ServingCertFile)
+	if err != nil {
+		return nil, err
+	}
+	keyBytes, err := ioutil.ReadFile(o.ServingKeyFile)
+	if err != nil {
+		return nil, err
+	}
+	certificate, err := tls.X509KeyPair(certBytes, keyBytes)
+	if err != nil {
+		return nil, err
+	}
+
+	return crypto.SecureTLSConfig(&tls.Config{
+		GetCertificate: func(_ *tls.ClientHelloInfo) (*tls.Certificate, error) {
+			return &certificate, nil
+		},
+	}), nil
+}
+
 // run launches a number of goroutines to handle manifest application,
 // metrics serving, etc.  It continues operating until ctx.Done(),
 // and then attempts a clean shutdown limited by an internal context
@@ -159,10 +196,18 @@ func (o *Options) run(ctx context.Context, controllerCtx *Context, lock *resourc
 	resultChannel := make(chan asyncResult, 1)
 	resultChannelCount := 0
 	if o.ListenAddr != "" {
+		var tlsConfig *tls.Config
+		if o.ServingCertFile != "" || o.ServingKeyFile != "" {
+			var err error
+			tlsConfig, err = o.makeTLSConfig()
+			if err != nil {
+				klog.Fatalf("Failed to create TLS config: %v", err)
+			}
+		}
 		resultChannelCount++
 		go func() {
 			defer utilruntime.HandleCrash()
-			err := cvo.RunMetrics(postMainContext, shutdownContext, o.ListenAddr)
+			err := cvo.RunMetrics(postMainContext, shutdownContext, o.ListenAddr, tlsConfig)
 			resultChannel <- asyncResult{name: "metrics server", error: err}
 		}()
 	}
@@ -171,6 +216,7 @@ func (o *Options) run(ctx context.Context, controllerCtx *Context, lock *resourc
 	// FIXME: would be nice if there was a way to collect these.
 	controllerCtx.CVInformerFactory.Start(informersDone)
 	controllerCtx.OpenshiftConfigInformerFactory.Start(informersDone)
+	controllerCtx.OpenshiftConfigManagedInformerFactory.Start(informersDone)
 	controllerCtx.InformerFactory.Start(informersDone)
 
 	resultChannelCount++
@@ -187,7 +233,7 @@ func (o *Options) run(ctx context.Context, controllerCtx *Context, lock *resourc
 					resultChannelCount++
 					go func() {
 						defer utilruntime.HandleCrash()
-						err := controllerCtx.CVO.Run(runContext, shutdownContext, 2)
+						err := controllerCtx.CVO.Run(runContext, 2)
 						resultChannel <- asyncResult{name: "main operator", error: err}
 					}()
 
@@ -347,9 +393,10 @@ type Context struct {
 	CVO        *cvo.Operator
 	AutoUpdate *autoupdate.Controller
 
-	CVInformerFactory              externalversions.SharedInformerFactory
-	OpenshiftConfigInformerFactory informers.SharedInformerFactory
-	InformerFactory                externalversions.SharedInformerFactory
+	CVInformerFactory                     externalversions.SharedInformerFactory
+	OpenshiftConfigInformerFactory        informers.SharedInformerFactory
+	OpenshiftConfigManagedInformerFactory informers.SharedInformerFactory
+	InformerFactory                       externalversions.SharedInformerFactory
 }
 
 // NewControllerContext initializes the default Context for the current Options. It does
@@ -362,14 +409,16 @@ func (o *Options) NewControllerContext(cb *ClientBuilder) *Context {
 		opts.FieldSelector = fmt.Sprintf("metadata.name=%s", o.Name)
 	})
 	openshiftConfigInformer := informers.NewSharedInformerFactoryWithOptions(kubeClient, resyncPeriod(o.ResyncInterval)(), informers.WithNamespace(internal.ConfigNamespace))
+	openshiftConfigManagedInformer := informers.NewSharedInformerFactoryWithOptions(kubeClient, resyncPeriod(o.ResyncInterval)(), informers.WithNamespace(internal.ConfigManagedNamespace))
 
 	sharedInformers := externalversions.NewSharedInformerFactory(client, resyncPeriod(o.ResyncInterval)())
 
 	coInformer := sharedInformers.Config().V1().ClusterOperators()
 	ctx := &Context{
-		CVInformerFactory:              cvInformer,
-		OpenshiftConfigInformerFactory: openshiftConfigInformer,
-		InformerFactory:                sharedInformers,
+		CVInformerFactory:                     cvInformer,
+		OpenshiftConfigInformerFactory:        openshiftConfigInformer,
+		OpenshiftConfigManagedInformerFactory: openshiftConfigManagedInformer,
+		InformerFactory:                       sharedInformers,
 
 		CVO: cvo.New(
 			o.NodeName,
@@ -381,6 +430,7 @@ func (o *Options) NewControllerContext(cb *ClientBuilder) *Context {
 			cvInformer.Config().V1().ClusterVersions(),
 			coInformer,
 			openshiftConfigInformer.Core().V1().ConfigMaps(),
+			openshiftConfigManagedInformer.Core().V1().ConfigMaps(),
 			sharedInformers.Config().V1().Proxies(),
 			cb.ClientOrDie(o.Namespace),
 			cb.KubeClientOrDie(o.Namespace, useProtobuf),
